# codebase-intelligence
🧩 Tibo – CLI tool for codebase indexing, call graph generation, and chunking into a vector database. Enables natural language queries to retrieve context relevant files, functions, and code chunks.
